@@ -43,7 +43,7 @@ from . import clone_vm
 
 from .appmenu_select import AppmenuSelectManager
 from . import firewall
-from PyQt5 import QtCore, QtWidgets, QtGui  # pylint: disable=import-error
+from PyQt5 import QtCore, QtWidgets, QtGui, Qt  # pylint: disable=import-error
 
 from . import ui_settingsdlg  # pylint: disable=no-name-in-module
 
@@ -151,6 +151,9 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
         self.setupUi(self)
         self.setWindowTitle(self.tr("Settings: {vm}").format(vm=self.vm.name))
+        self.setWindowFlags(self.windowFlags() |
+                            Qt.Qt.WindowMaximizeButtonHint |
+                            Qt.Qt.WindowMinimizeButtonHint)
         if init_page in self.tabs_indices:
             idx = self.tabs_indices[init_page]
             assert idx in range(self.tabWidget.count())
@@ -482,6 +485,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
         except qubesadmin.exc.QubesDaemonAccessError:
             self.autostart_vm.setEnabled(False)
         except AttributeError:
+            self.autostart_vm.setEnabled(False)
             self.autostart_vm.setVisible(False)
 
         # type
@@ -540,9 +544,8 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
         # vm label changed
         try:
-            if self.vmlabel.isVisible():
-                if utils.did_widget_selection_change(self.vmlabel):
-                    self.vm.label = self.vmlabel.currentData()
+            if utils.did_widget_selection_change(self.vmlabel):
+                self.vm.label = self.vmlabel.currentData()
         except qubesadmin.exc.QubesException as ex:
             msg.append(str(ex))
 
@@ -571,7 +574,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
         # autostart_vm
         try:
-            if self.autostart_vm.isVisible():
+            if self.autostart_vm.isEnabled():
                 if self.vm.autostart != self.autostart_vm.isChecked():
                     self.vm.autostart = self.autostart_vm.isChecked()
         except qubesadmin.exc.QubesException as ex:
@@ -827,7 +830,9 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
                 self.kernel_opts.setText(getattr(self.vm, 'kernelopts', '-'))
             except qubesadmin.exc.QubesDaemonAccessError:
                 self.kernel_groupbox.setVisible(False)
+                self.kernel.setEnabled(False)
         else:
+            self.kernel.setEnabled(False)
             self.kernel_groupbox.setVisible(False)
 
         if not hasattr(self.vm, 'default_dispvm'):
@@ -887,6 +892,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
             self.run_in_debug_mode.setVisible(True)
         except AttributeError:
             self.run_in_debug_mode.setVisible(False)
+            self.run_in_debug_mode.setEnabled(False)
 
         utils.initialize_widget(
             widget=self.allow_fullscreen,
@@ -958,7 +964,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
             msg.append(str(ex))
 
         # in case VM is not Linux
-        if hasattr(self.vm, "kernel") and self.kernel_groupbox.isVisible():
+        if hasattr(self.vm, "kernel"):
             try:
                 if utils.did_widget_selection_change(self.kernel):
                     self.vm.kernel = self.kernel.currentData()
@@ -999,7 +1005,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
 
         # run_in_debug_mode
         try:
-            if self.run_in_debug_mode.isVisible():
+            if self.run_in_debug_mode.isEnabled():
                 if self.vm.debug != self.run_in_debug_mode.isChecked():
                     self.vm.debug = self.run_in_debug_mode.isChecked()
         except qubesadmin.exc.QubesException as ex:
@@ -1237,7 +1243,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
                     self.vm.devices['pci'].detach(current_assignment)
 
                     current_assignment.options['no-strict-reset'] = \
-                        (dev.ident in self.new_strict_reset_list)
+                        dev.ident in self.new_strict_reset_list
 
                     self.vm.devices['pci'].attach(current_assignment)
 
@@ -1400,7 +1406,7 @@ class VMSettingsWindow(ui_settingsdlg.Ui_SettingsDialog, QtWidgets.QDialog):
             for i in range(self.services_list.count()):
                 item = self.services_list.item(i)
                 self.new_srv_dict[str(item.text())] = \
-                    (item.checkState() == ui_settingsdlg.QtCore.Qt.Checked)
+                    item.checkState() == ui_settingsdlg.QtCore.Qt.Checked
 
             for service, v in self.new_srv_dict.items():
                 feature = SERVICE_PREFIX + service
